@@ -3,21 +3,25 @@ package Catalyst::Plugin::Singleton;
 use strict;
 use Scalar::Util;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 *context = \&instance;
 
 sub instance {
     my $class = shift;
 
-    return $class::_instance;
+    no strict 'refs';
+    return ${"$class\::_instance"};
 }
 
 sub prepare {
     my $class   = shift;
     my $context = $class->NEXT::prepare(@_);
 
-    Scalar::Util::weaken( $class::_instance = $context );
+    {
+        no strict 'refs';
+        Scalar::Util::weaken( ${"$class\::_instance"} = $context );
+    }
 
     return $context;
 }
@@ -41,7 +45,29 @@ Catalyst::Plugin::Singleton - Singleton to context
 
 =head1 DESCRIPTION
 
-Singleton to context.
+Singleton accessors to context.
+
+=head1 METHODS
+
+=over 4
+
+=item context
+
+alias for instance 
+
+=item instance
+
+Returns the current instance of the context object.
+
+=back 
+
+=head1 OVERRIDES
+
+=over 4
+
+=item prepare
+
+=back
 
 =head1 SEE ALSO
 
@@ -53,7 +79,7 @@ Christian Hansen, C<ch@ngmedia.com>
 
 =head1 LICENSE
 
-This library is free software. You can redistribute it and/or modify it under
-the same terms as perl itself.
+This library is free software. You can redistribute it and/or modify 
+it under the same terms as perl itself.
 
 =cut
